//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[SuankoTanki](-suanko-tanki.md)

# SuankoTanki

[common]\
val [SuankoTanki](-suanko-tanki.md): [Yaku](../-yaku/index.md)

四暗刻单骑
